@@ -1,4 +1,4 @@
-# $Id: Context.pm,v 1.10 2001/10/27 03:15:24 fil Exp $
+# $Id: Context.pm,v 1.11 2002/06/07 08:30:46 fil Exp $
 package JAAS::Object::Context;
 
 use strict;
@@ -9,7 +9,7 @@ use Storable qw(dclone);
 
 use vars qw($VERSION);
 
-$VERSION="0.02";
+$VERSION="0.03";
 
 $JAAS::Object::Context::VERSION="0.2";
 BEGIN {
@@ -869,12 +869,15 @@ As The Rock says, "Know Your Role!".
 
 =head1 AUTHOR
 
-Learry Gagne <gagnel@artware.qc.ca>, 
-Philip Gwyn <gwynp@artware.qc.ca>
+Philip Gwyn <jaas at awale.qc.ca>, 
+Learry Gagn <mou-jaas at awale.qc.ca>.
 
 =cut
 
 $Log: Context.pm,v $
+Revision 1.11  2002/06/07 08:30:46  fil
+Bumped version
+
 Revision 1.10  2001/10/27 03:15:24  fil
 Fixed some warning messages.
 
